# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import frontoffice
from frontoffice.api.developer_tools_api import DeveloperToolsApi  # noqa: E501
from frontoffice.rest import ApiException


class TestDeveloperToolsApi(unittest.TestCase):
    """DeveloperToolsApi unit test stubs"""

    def setUp(self):
        self.api = frontoffice.api.developer_tools_api.DeveloperToolsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_contact_v2_dev_contact_get(self):
        """Test case for get_contact_v2_dev_contact_get

        Get Contact  # noqa: E501
        """
        pass

    def test_get_settings_v2_dev_settings_get(self):
        """Test case for get_settings_v2_dev_settings_get

        Get Settings  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
