# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import frontoffice
from frontoffice.models.contactpersoon_gegevens import ContactpersoonGegevens  # noqa: E501
from frontoffice.rest import ApiException

class TestContactpersoonGegevens(unittest.TestCase):
    """ContactpersoonGegevens unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ContactpersoonGegevens
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = frontoffice.models.contactpersoon_gegevens.ContactpersoonGegevens()  # noqa: E501
        if include_optional :
            return ContactpersoonGegevens(
                email = '0', 
                adressen = [
                    frontoffice.models.adres_mutatie.AdresMutatie(
                        soort = 'Domicilie', 
                        postcode = '0', 
                        straat = '0', 
                        land = '0', 
                        huisnummer = 56, 
                        huisnummertoevoeging = '0', 
                        landnaam = '0', 
                        verwijderd = True, 
                        einddatum = '0', )
                    ], 
                kanaalvoorkeur = 'POST', 
                nieuwsbrief = True, 
                klanttevredenheidsonderzoek = True, 
                magazine = 'POST', 
                telefoonnummer1 = 'a', 
                telefoonnummer2 = 'a', 
                email_adresseerbaar = True, 
                voornaam = '0', 
                achternaam = '0', 
                werkgevernummer = '0', 
                functie = '0', 
                actief = True, 
                aanhef = '0', 
                tussenvoegsel = '0'
            )
        else :
            return ContactpersoonGegevens(
        )

    def testContactpersoonGegevens(self):
        """Test ContactpersoonGegevens"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
