# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import frontoffice
from frontoffice.api.contactgegevens_api import ContactgegevensApi  # noqa: E501
from frontoffice.rest import ApiException


class TestContactgegevensApi(unittest.TestCase):
    """ContactgegevensApi unit test stubs"""

    def setUp(self):
        self.api = frontoffice.api.contactgegevens_api.ContactgegevensApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get(self):
        """Test case for get_events_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_get

        Get Events  # noqa: E501
        """
        pass

    def test_get_search_core_v2_search_core_administratie_get(self):
        """Test case for get_search_core_v2_search_core_administratie_get

        Get Search Core  # noqa: E501
        """
        pass

    def test_get_search_pere_v2_search_pere_administratie_get(self):
        """Test case for get_search_pere_v2_search_pere_administratie_get

        Get Search Pere  # noqa: E501
        """
        pass

    def test_get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get(self):
        """Test case for get_snapshot_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_get

        Get Snapshot  # noqa: E501
        """
        pass

    def test_put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post(self):
        """Test case for put_event_v2_contactgegevens_administratie_relatiesoort_persoonsnummer_events_post

        Put Event  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
