# coding: utf-8

"""
    MN Frontoffice CORE & PERE

    Highly available and searchable datastore for MN  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import frontoffice
from frontoffice.models.adres_mutatie import AdresMutatie  # noqa: E501
from frontoffice.rest import ApiException

class TestAdresMutatie(unittest.TestCase):
    """AdresMutatie unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AdresMutatie
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = frontoffice.models.adres_mutatie.AdresMutatie()  # noqa: E501
        if include_optional :
            return AdresMutatie(
                soort = 'Domicilie', 
                postcode = '0', 
                straat = '0', 
                land = '0', 
                huisnummer = 56, 
                huisnummertoevoeging = '0', 
                landnaam = '0', 
                verwijderd = True, 
                einddatum = '0'
            )
        else :
            return AdresMutatie(
                soort = 'Domicilie',
        )

    def testAdresMutatie(self):
        """Test AdresMutatie"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
